import React from 'react'
import {ScreensSchema} from 'system/screens'


export const screensSchema: ScreensSchema = {
/* (%%items%%) */
}
